@@ -126,7 +126,7 @@ bicomprisk <- function(formula, data, cause=c(1,1), cens=0, causes, indiv,
   ww0 <- reshape(data[,c(timevar,causes,covars,indiv,id,num,"lse.clusters")],
          direction="wide",idvar=id,timevar=num)[,c(id,"lse.clusters.1",timevar2,causes2,indiv2,covars2)]
   else 
-  ww0 <- fast.reshape(data[,c(timevar,causes,covars,indiv,id,num,"lse.clusters")],id=id,num=data$num)[,c(id,"lse.clusters1",timevar2,causes2,indiv2,covars2)]
+  ww0 <- fast.reshape(data[,c(timevar,causes,covars,indiv,id,num,"lse.clusters")],id=id,num=data$num,labelnum=TRUE)[,c(id,"lse.clusters1",timevar2,causes2,indiv2,covars2)]
   ww0 <- na.omit(ww0)
  
   status <- rep(0,nrow(ww0))
