@@ -15,24 +15,32 @@
 ##' @examples
 ##' set.seed(1)
 ##' d <- subset(simClaytonOakes(500,4,2,1,stoptime=2,left=2),!truncated)
-##' e <- ClaytonOakes(Surv(lefttime,time,status)~x1+cluster(~1,cluster),cuts=c(0,0.5,1,2),data=d)
+##' e <- ClaytonOakes(Surv(lefttime,time,status)~x1+cluster(~1,cluster),
+##'                   cuts=c(0,0.5,1,2),data=d)
 ##' e
 ##' 
 ##' 
 ##' d2 <- simClaytonOakes(500,4,2,1,stoptime=2,left=0)
 ##' d2$z <- rep(1,nrow(d2)); d2$z[d2$cluster%in%sample(d2$cluster,100)] <- 0
-##' ts <- ClaytonOakes(Surv(time,status)~prop(x1)+cluster(~1,cluster),data=d2,type="two.stage") ## Marginal: Cox Proportional Hazards model
-##' ts2 <- ClaytonOakes(Surv(time,status)~x1+cluster(~1,cluster),data=d2,type="two.stage") ## Marginal: Aalens additive model
-##' e2 <- ClaytonOakes(Surv(time,status)~x1+cluster(~-1+factor(z),cluster),cuts=c(0,0.5,1,2),data=d2) ## Marginal: Piecewise constant
+##' ## Marginal=Cox Proportional Hazards model:
+##' ts <- ClaytonOakes(Surv(time,status)~prop(x1)+cluster(~1,cluster),
+##'                    data=d2,type="two.stage")
+##' ## Marginal=Aalens additive model:
+##' ts2 <- ClaytonOakes(Surv(time,status)~x1+cluster(~1,cluster),
+##'                     data=d2,type="two.stage")
+##' ## Marginal=Piecewise constant:
+##' e2 <- ClaytonOakes(Surv(time,status)~x1+cluster(~-1+factor(z),cluster),
+##'                    cuts=c(0,0.5,1,2),data=d2)
 ##' e2
 ##' plot(ts)
 ##' plot(e2,add=TRUE)
 ##' 
-##' e3 <- ClaytonOakes(Surv(time,status)~x1+cluster(~1,cluster),cuts=c(0,0.5,1,2),data=d,var.invlink=identity)
+##' e3 <- ClaytonOakes(Surv(time,status)~x1+cluster(~1,cluster),cuts=c(0,0.5,1,2),
+##'                    data=d,var.invlink=identity)
 ##' e3
 ##' @export
 ClaytonOakes <- function(formula,data=parent.frame(),cluster,var.formula=~1,cuts=NULL,type="piecewise",start,control=list(),var.invlink=exp,...) {
-  
+
   mycall <- match.call()
   dots <- list(...)
   formulaId <- Specials(formula,"cluster") 
@@ -134,12 +142,11 @@ ClaytonOakes <- function(formula,data=parent.frame(),cluster,var.formula=~1,cuts
       multhaz <- exp(X%*%beta)
     }
     if (!is.null(dots$theta)) theta0 <- cbind(rep(dots$theta,length(theta0)))
-    ##    browser()
     res <- .Call("claytonoakes",
            ds=mydata$status,ts=mydata$T,es=mydata$entry,
-           allcs=mydata$cluster,cs=ucluster,
-           cuts=cuts,hs=exp(p),mulths=multhaz,
-           var=theta0,DUP=FALSE)$logLik
+           allcs=mydata$cluster,cs=ucluster, cuts=cuts,
+                 hs=exp(p),mulths=multhaz,
+                 var=theta0)$logLik
     return(-res)
   }
   opt <- tryCatch(nlminb(p0,obj,control=control),error=function(x) NULL)
