@@ -5,7 +5,7 @@ logLik.biprobit <- function(object,indiv=FALSE,...) {
   p <- length(coef(object))
   loglik <- sum(object$logLik)
   attr(loglik, "nall") <- n
-  attr(loglik, "nobs") <- n-p
+  attr(loglik, "nobs") <- n
   attr(loglik, "df") <- p
   class(loglik) <- "logLik"        
   return(loglik)
